from machine import Pin
import network
import socket
import secrets
import webresponses
import time

# Built in blue LED connected to pin labeled PA0 on the board
Led = Pin(10, Pin.OUT)

# signal power on
Led.on()
time.sleep(2)
Led.off()
time.sleep(1)  

ledstatus = 0   

def toggleled():
  global ledstatus
  ledstatus = 1-ledstatus
  Led.value(ledstatus)
  print('LED turned {}'.format("on" if ledstatus else "off")) 

CONNECT_TIMEOUT = 20

sta_if = network.WLAN(network.STA_IF)

# loop until connection to Wi-Fi network made
attempt = 1
while not sta_if.isconnected():
  sta_if.active(True)
  print('Network connection attempt {}...'.format(attempt))
  attempt += 1
  sta_if.connect(secrets.STA_SSID, secrets.STA_PSWD)
  for i in range(CONNECT_TIMEOUT):
    if sta_if.isconnected():
      break;
    else:
      time.sleep(1)

sta_if.ifconfig((secrets.STA_FIXED_IP, secrets.STA_SUBNET, secrets.STA_GATEWAY, secrets.STA_DNS))
print("Successful connection to {} in less {} seconds.".format(secrets.STA_SSID, attempt))

s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
# avoid [Errno 112] EADDRINUSE on restarting the script quickly
# https://forum.micropython.org/viewtopic.php?t=10412#p57684
s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
# Binding to all interfaces - server will be accessible to other hosts!
s.bind(('0.0.0.0', 80))
s.listen(3)
print('Web server started at http://' + sta_if.ifconfig()[0])
print('Click on Quit button to stop the script')

# signal web server started
for i in range(5):
  for j in range(2):  
      Led.on()
      time.sleep_ms(50)
      Led.off()
      time.sleep_ms(50)
  time.sleep_ms(250)

Led.off()       # LED initially off
ledstatus = 0   

while True:
  conn, addr = s.accept()
  print()
  print('Client connection from {}'.format(addr))
  request = conn.recv(1024)
  request = str(request)
  print('Resquest {}...'.format(request[0:31]))
  if request.find('/quit ') == 6:
    reply  = 1  # quit          
  elif request.find('/?led=toggle ') == 6:
    toggleled()
    reply = 0      #  show index.html
  elif request.find('/ ') == 6:
    reply = 0      # show index.html
  else:
    reply = -1     # not found error
  rh1, rh2, rh3 = webresponses.HttpResponseHeader(reply < 0)
  #print('rh1: {}, rh2: {}, rh3: {}'.format(rh1, rh2, rh3))
  conn.send(rh1)
  if reply < 1:
    conn.send(rh2)
    conn.send(rh3)
    conn.sendall(webresponses.HttpPage(reply < 0, ledstatus))
  conn.close()
  if reply == 1:
    break

